==> 0.1.66.tar.gz: android/src/main/java/com/medipreco/loopboxplugin/LoopboxBasicChannel.java <==
package com.medipreco.loopboxplugin;

import android.annotation.TargetApi;
import android.bluetooth.BluetoothAdapter;
import android.os.Build;
import android.util.Log;
import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.StringCodec;

public class LoopboxBasicChannel {

  private static final String DEVICES_NEARBY_EVENT = "com.medipreco.loopboxplugin/devices/nearby";
  private static final String UNLOCK_EVENT = "com.medipreco.loopboxplugin/devices/unlock";
  private static final String BLUETOOTH_CHECK = "com.medipreco.loopboxplugin/check/bluetooth";

  private BasicMessageChannel basicMessageChannel;

  private BasicMessageChannel basicMessageUnlockChannel;

  private BasicMessageChannel basicMessageBluetoothChannel;

  private static LoopboxBasicChannel instance;

  private LoopboxBasicChannel() {

  }

  public static LoopboxBasicChannel getInstance() {
    if(instance == null) {
      instance = new LoopboxBasicChannel();
    }

    return instance;
  }

  @TargetApi(Build.VERSION_CODES.ECLAIR)
  public void checkBluetooth() {
    BluetoothAdapter mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
    if (mBluetoothAdapter == null) {
      Log.d("LoopboxP", "Bluetooth nao suportado");
      this.basicMessageBluetoothChannel.send("DEACTIVE");
    } else {
      if (!mBluetoothAdapter.isEnabled()) {
        Log.d("LoopboxP", "Bluetooth desativado");
        this.basicMessageBluetoothChannel.send("DEACTIVE");
      } else {
        Log.d("LoopboxP", "Bluetooth ativado");
        this.basicMessageBluetoothChannel.send("ACTIVE");
      }
    }
  }

  public void setupEventChannel(BinaryMessenger messenger) {
    this.basicMessageChannel = new BasicMessageChannel<String>(
        messenger,
        DEVICES_NEARBY_EVENT,
        StringCodec.INSTANCE);

    this.basicMessageChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<String>() {
      @Override
      public void onMessage(String s, BasicMessageChannel.Reply<String> reply) {
        reply.reply("");
      }
    });

    this.basicMessageUnlockChannel = new BasicMessageChannel<String>(
        messenger,
        UNLOCK_EVENT,
        StringCodec.INSTANCE
    );

    this.basicMessageUnlockChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<String>() {
      @Override
      public void onMessage(String s, BasicMessageChannel.Reply<String> reply) {
        reply.reply("");
      }
    });

    this.basicMessageBluetoothChannel = new BasicMessageChannel<String>(
        messenger,
        BLUETOOTH_CHECK,
        StringCodec.INSTANCE
    );

    this.basicMessageBluetoothChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<String>() {
      @Override
      public void onMessage(String s, BasicMessageChannel.Reply<String> reply) {
        reply.reply("");
      }
    });
  }

  public void sendUnlockEvent(String msg) {
    this.basicMessageUnlockChannel.send(msg);
  }

  public void sendBluetoothCheck(String message) {
    this.basicMessageBluetoothChannel.send(message);
  }

  public void send(String msg) {
    this.basicMessageChannel.send(msg);
  }
}

==> 1.1.0.tar.gz: android/src/main/java/com/medipreco/loopboxplugin/LoopboxBasicChannel.java <==
package com.medipreco.loopboxplugin;

import android.annotation.TargetApi;
import android.bluetooth.BluetoothAdapter;
import android.os.Build;
import android.util.Log;
import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.StringCodec;

public class LoopboxBasicChannel {

  private static final String DEVICES_NEARBY_EVENT = "com.medipreco.loopboxplugin/devices/nearby";
  private static final String UNLOCK_EVENT = "com.medipreco.loopboxplugin/devices/unlock";
  private static final String BLUETOOTH_CHECK = "com.medipreco.loopboxplugin/check/bluetooth";

  private BasicMessageChannel basicMessageChannel;

  private BasicMessageChannel basicMessageUnlockChannel;

  private BasicMessageChannel basicMessageBluetoothChannel;

  private static LoopboxBasicChannel instance;

  private LoopboxBasicChannel() {

  }

  public static LoopboxBasicChannel getInstance() {
    if(instance == null) {
      instance = new LoopboxBasicChannel();
    }

    return instance;
  }

  @TargetApi(Build.VERSION_CODES.ECLAIR)
  public String checkBluetooth() {
    BluetoothAdapter mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
    if (mBluetoothAdapter == null) {
      Log.d("LoopboxP", "Bluetooth nao suportado");
      return "DEACTIVE";
    } else {
      if (!mBluetoothAdapter.isEnabled()) {
        Log.d("LoopboxP", "Bluetooth desativado");
        return "DEACTIVE";
      } else {
        Log.d("LoopboxP", "Bluetooth ativado");
        return "ACTIVE";
      }
    }
  }

  public void setupEventChannel(BinaryMessenger messenger) {
    this.basicMessageChannel = new BasicMessageChannel<String>(
        messenger,
        DEVICES_NEARBY_EVENT,
        StringCodec.INSTANCE);

    this.basicMessageChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<String>() {
      @Override
      public void onMessage(String s, BasicMessageChannel.Reply<String> reply) {
        reply.reply("");
      }
    });

    this.basicMessageUnlockChannel = new BasicMessageChannel<String>(
        messenger,
        UNLOCK_EVENT,
        StringCodec.INSTANCE
    );

    this.basicMessageUnlockChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<String>() {
      @Override
      public void onMessage(String s, BasicMessageChannel.Reply<String> reply) {
        reply.reply("");
      }
    });

    this.basicMessageBluetoothChannel = new BasicMessageChannel<String>(
        messenger,
        BLUETOOTH_CHECK,
        StringCodec.INSTANCE
    );

    this.basicMessageBluetoothChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<String>() {
      @Override
      public void onMessage(String s, BasicMessageChannel.Reply<String> reply) {
        reply.reply("");
      }
    });
  }

  public void sendUnlockEvent(String msg) {
    this.basicMessageUnlockChannel.send(msg);
  }

  public void sendBluetoothCheck(String message) {
    this.basicMessageBluetoothChannel.send(message);
  }

  public void send(String msg) {
    this.basicMessageChannel.send(msg);
  }
}
